mk_graphql library

Library for requesting GraphQl requests

Classes

BackupCacheStore
A store saving responses in a dedicated primary store and secondary store.
CacheCipher
CacheControl
Cache-Control header subset representation
CacheOptions
Options to apply to handle request and cache behaviour.
CacheResponse
Response representation from cache store.
CacheStore
Definition of store
DioCacheInterceptor
Cache interceptor
GraphBaseOptions
Base options for graphql request
GraphClient
client for requesting graphql requests
GraphRequest
GraphResult
Graphql result
MemCacheStore
A store saving responses in a dedicated memory LRU map.
Nullable<T>
ResponseParser
JSON Response parser

Enums

CachePolicy
Policy to handle request behaviour.
CachePriority
Cache priority.

Typedefs

CacheKeyBuilder = String Function(RequestOptions request)
Key builder to customize your keys.
Decrypt = Future<List<int>> Function(List<int> bytes)
Decrypt content/headers method.
Encrypt = Future<List<int>> Function(List<int> bytes)
Encrypt content/headers method.

Exceptions / Errors

GraphqlException
Graphql exception