mk_graphql library
Library for requesting GraphQl requests
Classes
- BackupCacheStore
- A store saving responses in a dedicated primary store and secondary store.
- CacheCipher
- CacheControl
- Cache-Control header subset representation
- CacheOptions
- Options to apply to handle request and cache behaviour.
- CacheResponse
- Response representation from cache store.
- CacheStore
- Definition of store
- DioCacheInterceptor
- Cache interceptor
- GraphBaseOptions
- Base options for graphql request
- GraphClient
- client for requesting graphql requests
- GraphRequest
- GraphResult
- Graphql result
- MemCacheStore
- A store saving responses in a dedicated memory LRU map.
-
Nullable<
T> - ResponseParser
-
JSON
Responseparser
Enums
- CachePolicy
- Policy to handle request behaviour.
- CachePriority
- Cache priority.
Extensions
Typedefs
Exceptions / Errors
- GraphqlException
- Graphql exception